@@ -7,7 +7,6 @@ import os
 table = ""
 
 pick_table = '''
-
 >>  Select preferred table output below.
 	A:  Case Details
 	B:  Fee Sheets
@@ -17,9 +16,8 @@ pick_table = '''
 
 Enter A, B, C, D, or E to continue:
 
-	     '''
+'''
 just_table = '''
-
 >>  EXPORT DATA TABLE:
 
 	To export data table from case inputs, enter 
@@ -29,9 +27,7 @@ just_table = '''
 
 Enter path:
 
-	'''
-
-
+'''
 both =  '''
 >>  EXPORT FULL TEXT ARCHIVE:
 
@@ -48,7 +44,7 @@ both =  '''
 
 Enter path:
 
-	'''
+'''
 title = '''
 	    ___    __                          __
 	   /   |  / /___  _________  _________/ /__  _____
@@ -74,6 +70,7 @@ title = '''
 	|------------------------------------------------------|
 
 Enter input and output paths: 
+
 '''
 
 text_p = '''
@@ -82,11 +79,6 @@ Enter path to output text file (must be .txt):
 
 '''
 
-def print_version(ctx,param,value):
-	return "ALACORDER beta 73.6.2"
-	ctx.exit()
-
-
 def pickTable():
 	pick = "".join(input())
 	if pick == "A":
@@ -115,8 +107,8 @@ def splitext(path: str):
 	})
 
 @click.command()
-@click.option('--input-path','-in',required=True,prompt=title)
-@click.option('--output-path','-out',prompt=both,default="NONE")
+@click.option('--input-path','-in',required=True,prompt=title,help="Path to input archive or PDF directory")
+@click.option('--output-path','-out',prompt=both,help="Path to output table (.xls, .xlsx, .csv, .json, .dta) or archive (.pkl.xz)")
 @click.option('--table', show_default=False, help="Table export choice")
 @click.option('--archive',type=bool, is_flag=True, default=False, help='Write archive to output.pkl.xz')
 @click.option('--count',default=0, help='Max cases to pull from input',show_default=False)
@@ -127,19 +119,13 @@ def splitext(path: str):
 @click.option('--no-write', default=False, is_flag=True, help="Do not export to output path",hidden=True) # not yet func
 @click.option('--dedupe', default=False, is_flag=True, help="Remove duplicate cases from input archive") # not yet func
 @click.option('--pager', default=False, is_flag=True, help="Open pager view of outputs upon completion")
-@click.option('--version', default="", help="Print version number", expose_value=False, is_eager=True,callback=print_version, hidden=True)
-def cli(input_path, output_path, table, archive, count, no_bar, warn, overwrite, launch, no_write, dedupe, pager, version="beta"):
+def cli(input_path, output_path, table, archive, count, no_bar, warn, overwrite, launch, no_write, dedupe, pager):
 	"""
-
-	ALACORDER beta 73	
+	ALACORDER beta 73 
 
 	Alacorder processes case detail PDFs into data tables suitable for research purposes. Alacorder also generates compressed text archives from the source PDFs to speed future data collection from the same set of cases.
 
-
-	© 2023 Sam Robson
-
-	https://github.com/sbrobson959/alacorder
-	
+	© 2023 Sam Robson	https://github.com/sbrobson959/alacorder
 	"""
 
 	path = input_path
@@ -177,9 +163,10 @@ def cli(input_path, output_path, table, archive, count, no_bar, warn, overwrite,
 	if overwrite == False and (outcheck == "overwrite_archive" or outcheck == "overwrite_table" or outcheck == "overwrite_all_tables"):
 		if click.confirm("Warning: Existing file at output path will be written over! Continue in OVERWRITE MODE?"):
 			overwrite = True
+			archive = True
 	if overwrite == False and outcheck == "existing_archive":
 		if click.confirm("Appending to existing file at output path. Continue?"):
-			pass
+			archive = True
 
 	if outcheck == "archive" or outcheck == "existing_archive":
 		supportTable = False
@@ -211,7 +198,6 @@ def cli(input_path, output_path, table, archive, count, no_bar, warn, overwrite,
 		c = a[b == True]
 		b = alac.writeArchive(a)
 
-	if supportTable or supportArchive and bool(output)==False:
 
 	if supportTable and (outcheck == "table" or outcheck == "overwrite_table"):
 		pick = click.getchar(pick_table)
